import { devServer as devServer$1 } from '@cypress/webpack-dev-server';
import { writeFileSync } from 'fs';
import { join } from 'path';
import { AngularWebpackPlugin } from '@ngtools/webpack';
import { dirSync } from 'tmp';

const generateTsConfigContent = (specPattern, projectRoot) => {
    const getFilePath = (fileName) => join(projectRoot, fileName);
    const getCySupportFile = join(projectRoot, 'cypress/support/component.ts');
    const getIncludePaths = () => {
        if (Array.isArray(specPattern)) {
            return [...specPattern.map(sp => getFilePath(sp)), getCySupportFile];
        }
        if (typeof specPattern === 'string') {
            return [getFilePath(specPattern), getCySupportFile];
        }
        return [];
    };
    return `
{
  "extends": "${getFilePath('tsconfig.json')}",
  "compilerOptions": {
    "outDir": "${getFilePath('out-tsc/cy')}",
    "types": ["${getFilePath('node_modules/cypress')}"],
    "allowSyntheticDefaultImports": true
  },
  "include": [${getIncludePaths().map(x => `"${x}"`)}]
}
`;
};
const generateTsConfig = (specPattern, projectRoot, tempDir) => {
    const tsconfigContent = generateTsConfigContent(specPattern, projectRoot);
    writeFileSync(`${tempDir}/tsconfig.cy.json`, tsconfigContent);
};

async function getWebpackConfig(tmpDir) {
    return {
        mode: 'development',
        module: {
            rules: [
                {
                    test: /\.[jt]sx?$/,
                    loader: '@ngtools/webpack',
                },
                {
                    test: /(\.scss|\.sass)$/,
                    use: ['raw-loader', 'sass-loader'],
                },
                {
                    test: /\.css$/,
                    loader: 'raw-loader',
                },
                {
                    test: /\.html$/,
                    loader: 'raw-loader'
                },
                {
                    // See https://angular.io/guide/creating-libraries#consuming-partial-ivy-code-outside-the-angular-cli
                    test: /\.m?js$/,
                    use: {
                        loader: 'babel-loader',
                        options: {
                            plugins: ['@angular/compiler-cli/linker/babel'],
                            compact: false,
                            cacheDirectory: true
                        }
                    }
                }
            ],
        },
        resolve: {
            extensions: ['.ts', '.js'],
        },
        plugins: [
            new AngularWebpackPlugin({
                tsconfig: `${tmpDir}/tsconfig.cy.json`
            }),
        ],
    };
}

async function devServer(cypressDevServerConfig) {
    const { config } = cypressDevServerConfig;
    const { specPattern, projectRoot } = config;
    // This creates a temporary directory used to store a tsconfig.cy.json file needed to construct the AngularWebpackPlugin
    const { name: tempDir } = dirSync();
    // This generates the tsconfig.cy.json file in the temporary directory from above
    generateTsConfig(specPattern, projectRoot, tempDir);
    const webpackConfig = await getWebpackConfig(tempDir);
    return devServer$1(cypressDevServerConfig, { webpackConfig });
}

/*
 * Public API Surface of angular-dev-server
 */

/**
 * Generated bundle index. Do not edit.
 */

export { devServer };
//# sourceMappingURL=cypress-angular-dev-server.mjs.map
